==> webkit2gtk_2.48.7.orig.tar.xz: webkitgtk-2.48.7/Source/WebCore/workers/service/NavigationPreloadManager.cpp <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "NavigationPreloadManager.h"

#include "ServiceWorkerContainer.h"
#include "ServiceWorkerRegistration.h"
#include <wtf/TZoneMallocInlines.h>

namespace WebCore {

WTF_MAKE_TZONE_ALLOCATED_IMPL(NavigationPreloadManager);

void NavigationPreloadManager::enable(Promise&& promise)
{
    m_registration.container().enableNavigationPreload(m_registration.identifier(), WTFMove(promise));
}

void NavigationPreloadManager::disable(Promise&& promise)
{
    m_registration.container().disableNavigationPreload(m_registration.identifier(), WTFMove(promise));
}

void NavigationPreloadManager::setHeaderValue(String&& value, Promise&& promise)
{
    m_registration.container().setNavigationPreloadHeaderValue(m_registration.identifier(), WTFMove(value), WTFMove(promise));
}

void NavigationPreloadManager::getState(StatePromise&& promise)
{
    m_registration.container().getNavigationPreloadState(m_registration.identifier(), WTFMove(promise));
}

} // namespace WebCore

==> webkit2gtk_2.50.1.orig.tar.xz: webkitgtk-2.50.1/Source/WebCore/workers/service/NavigationPreloadManager.cpp <==
/*
 * Copyright (C) 2021-2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "NavigationPreloadManager.h"

#include "ServiceWorkerContainer.h"
#include "ServiceWorkerRegistration.h"
#include <wtf/TZoneMallocInlines.h>

namespace WebCore {

WTF_MAKE_TZONE_ALLOCATED_IMPL(NavigationPreloadManager);

void NavigationPreloadManager::enable(Promise&& promise)
{
    Ref registration = m_registration.get();
    registration->container().enableNavigationPreload(registration->identifier(), WTFMove(promise));
}

void NavigationPreloadManager::disable(Promise&& promise)
{
    Ref registration = m_registration.get();
    registration->container().disableNavigationPreload(registration->identifier(), WTFMove(promise));
}

void NavigationPreloadManager::setHeaderValue(String&& value, Promise&& promise)
{
    Ref registration = m_registration.get();
    registration->container().setNavigationPreloadHeaderValue(registration->identifier(), WTFMove(value), WTFMove(promise));
}

void NavigationPreloadManager::getState(StatePromise&& promise)
{
    Ref registration = m_registration.get();
    registration->container().getNavigationPreloadState(registration->identifier(), WTFMove(promise));
}

} // namespace WebCore
